@@ -6,10 +6,21 @@
 phyl.pca<-function(tree,Y,method="BM",mode="cov"){
 	# check tree
 	if(class(tree)!="phylo") stop("tree must be an object of class 'phylo.'")
-
+	# check mode
+	if(length(strsplit(mode,split="")[[1]])<=2){ 
+		message(paste("mode = '",mode,"' not a valid option; setting mode = 'cov'",sep=""))
+		mode="cov"
+	}
+	if(all(strsplit(mode,split="")[[1]]==strsplit("correlation",split="")[[1]][1:length(strsplit(mode,split="")[[1]])]))
+		mode="corr"
+	else if(all(strsplit(mode,split="")[[1]]==strsplit("covariance",split="")[[1]][1:length(strsplit(mode,split="")[[1]])]))
+		mode="cov"
+	else {
+		message(paste("mode = '",mode,"' not a valid option; setting mode = 'cov'",sep=""))
+		mode="cov"
+	}
 	# preliminaries
 	n<-nrow(Y); m<-ncol(Y)
-
 	# check and sort data
 	if(n>length(tree$tip)) stop("number of rows in Y cannot be greater than number of taxa in your tree")
 	Y<-as.matrix(Y)
@@ -20,14 +31,13 @@ phyl.pca<-function(tree,Y,method="BM",mode="cov"){
 		} else stop("Y has no names and does not have the same number of rows as tips in tree")
 	} else if(length(setdiff(rownames(Y),tree$tip.label))!=0) 
 		stop("Y has rownames, but some rownames of Y not found in tree")
-
 	# analyze
 	C<-vcv.phylo(tree)[rownames(Y),rownames(Y)]
 	if(method=="BM"){ 
 		temp<-phyl.vcv(Y,C,1.0)
 		V<-temp$R; a<-t(temp$alpha); C<-temp$C
 	} else if(method=="lambda"){
-		temp<-optimize(f=likelihood,interval=c(0,1),X=Y,C=C,maximum=TRUE)
+		temp<-optimize(f=likMlambda,interval=c(0,maxLambda(tree)),X=Y,C=C,maximum=TRUE)
 		lambda<-temp$maximum; logL<-as.numeric(temp$objective)
 		temp<-phyl.vcv(Y,C,lambda)
 		V<-temp$R; a<-t(temp$alpha); C<-temp$C
@@ -52,48 +62,8 @@ phyl.pca<-function(tree,Y,method="BM",mode="cov"){
 		result$lambda<-lambda
 		result$logL.lambda<-logL
 	}
-	
 	# return result
 	return(result)
 }
 
-# function to compute phylogenetic VCV using joint Pagel's lambda
-# written by Liam Revell 2011
-phyl.vcv<-function(X,C,lambda){
-	C<-lambda.transform(lambda,C)
-	invC<-solve(C)
-	a<-matrix(colSums(invC%*%X)/sum(invC),ncol(X),1)
-	A<-matrix(rep(a,nrow(X)),nrow(X),ncol(X),byrow=T)
-	V<-t(X-A)%*%invC%*%(X-A)/(nrow(C)-1)
-	return(list(C=C,R=V,alpha=a))
-}
-
-# lambda transformation of C
-# written by Liam Revell 2011
-lambda.transform<-function(lambda,C){
-	if(lambda==1) return(C)
-	else {
-		V<-diag(diag(C))
-		C<-C-V
-		C.lambda<-(V+lambda*C)
-		return(C.lambda)
-	}
-}
-
-# likelihood function
-# written by Liam Revell 2011
-likelihood<-function(theta,X,C){
-	# compute R, conditioned on lambda
-	temp<-phyl.vcv(X,C,theta);
-	C<-temp$C; R<-temp$R; a<-temp$alpha
-	# prep
-	n<-nrow(X); m<-ncol(X); D<-matrix(0,n*m,m)
-	for(i in 1:(n*m)) for(j in 1:m) if((j-1)*n<i&&i<=j*n) D[i,j]=1.0
-	y<-as.matrix(as.vector(X))
-	# compute the log-likelihood
-	kronRC<-kronecker(R,C)
-	logL<--t(y-D%*%a)%*%solve(kronRC,y-D%*%a)/2-n*m*log(2*pi)/2-log(det(kronRC))/2
-	return(logL)
-}
-
 
